const cli = require('chalk');
const { fs } = require('@flk/fs');
const commander = require('@flk/commander');

commander
    .command('run', 'Execute all commands in flk.json file')
    .example('run')
    .then((command) => {
        new FileRunner(command);
    });

class FileRunner {
    constructor(command) {
        this.command = command;
        this.run();
    }

    async run() {
        let flkJsonFile = ROOT + '/flk.json';

        echo(cli.yellow(`Collecting ${cli.green('Commands')} from ${cli.yellow('flk.json')} file...`));

        let flkData = fs.getJson(flkJsonFile);

        let commandsList = flkData.commands;

        if (!commandsList) {
            return die(cli.redBright('No commands found'));
        }

        echo(`Found ${cli.green(Object.keys(commandsList).length)} command(s).`);

        for (let commandName in commandsList) {
            echo(`Executing ${cli.cyan(commandName)} command...`);
            let commandOperations = commandsList[commandName];

            for (let commandData of commandOperations) {
                let command = commander.getCommand(commandName);

                command.setArguments(commandData.arguments);
                command.setOptions(commandData.options);

                command.proceed();
            }
        }

        flkData.commands = {};

        fs.putJson(flkJsonFile, flkData);
    }
}

module.exports = FileRunner;